@@ -84,7 +84,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
